import"./E-vkuI0X.mjs";import{i as j}from"./DueIe5zz.mjs";import{p as w,h as s,r as a,al as p,b as C,c as D,d as N,aj as S,j as q,ak as A}from"./Dpn8_Hnn.mjs";import{s as B}from"./B4YZClIG.mjs";import{s as v}from"./CXHdal8Z.mjs";import{c as E,b as F,s as f}from"./mb_JAnfe.mjs";import{p as l}from"./CUWjGq9Z.mjs";import{p as G}from"./evd6y-9U.mjs";var H=q('<div><div class="position-relative"><h1 class="svelte-zuiu8u"> </h1> <div><!></div></div> <!></div>');function R(h,t){w(t,!1);const d=()=>A(G,"$pageTheme",_),[_,g]=S(),n=window.getComputedStyle(document.body).direction=="rtl";let b=l(t,"id",8,void 0),k=l(t,"class",8,""),T=l(t,"title",8);j();var e=H();let m;E(e,"",{},{"--gutter-block":"2px","--container-margin":"0"});var i=s(e),o=s(i),x=s(o,!0);a(o);var r=p(o,2);let u;var y=s(r);v(y,t,"tooltip",{}),a(r),a(i);var z=p(i,2);v(z,t,"default",{}),a(e),C(()=>{var c;F(e,"id",b()),m=f(e,1,`container ${(c=k())!=null?c:""}`,"svelte-zuiu8u",m,{light:!d().isDark,dark:d().isDark,rtl:n}),B(x,T()),u=f(r,1,"help-badge position-absolute svelte-zuiu8u",null,u,{rtl:n})}),D(h,e),N(),g()}export{R as T};
