import{g as c,s as r,a as f,b as g,c as u,d as y}from"./DTHo7gyJ.mjs";async function s(n,a){const t=new TextDecoder().decode((await a(n)).json);return JSON.parse(t)}async function o(n,a,e){const t=new TextEncoder,i=JSON.stringify(a);await e(n,t.encode(i))}async function d(n){return s(n,async a=>await f({val:a}))}async function l(n,a){return await o(n,a,async(e,t)=>await r({key:e,valueJson:t}))}async function J(n){return s(n,async a=>await g({val:a}))}async function C(n,a){return await o(n,a,async(e,t)=>await u({key:e,valueJson:t}))}async function v(n){return await s(n,async a=>await c({val:a}))}async function M(n,a){return await o(n,a,async(e,t)=>await y({key:e,valueJson:t,undoable:!0}))}export{l as a,d as b,J as c,C as d,v as g,M as s};
