import"./E-vkuI0X.mjs";import"./DueIe5zz.mjs";import{h as d,r as c,b as f,c as p,j as x}from"./Dpn8_Hnn.mjs";import{s as u}from"./CXHdal8Z.mjs";import{b as v,s as b}from"./mb_JAnfe.mjs";import{p as i}from"./CUWjGq9Z.mjs";var h=x("<div><!></div>");function y(n,e){let o=i(e,"id",8,void 0),l=i(e,"class",8,""),t=i(e,"breakpoint",8,"fluid");var a=h();let r;var m=d(a);u(m,e,"default",{}),c(a),f(()=>{var s;v(a,"id",o()),r=b(a,1,`container ${(s=l())!=null?s:""}`,"svelte-1qhanys",r,{"container-xs":t()==="xs","container-sm":t()==="sm","container-md":t()==="md","container-lg":t()==="lg","container-xl":t()==="xl","container-xxl":t()==="xxl","container-fluid":t()==="fluid"})}),p(n,a)}export{y as C};
