import"./E-vkuI0X.mjs";import{i as T}from"./DueIe5zz.mjs";import{p as j,l as f,s as r,i as b,g as s,a as k,h as B,r as x,b as D,c as M,d as N,ak as S,aj as W,m as p,j as q}from"./Dpn8_Hnn.mjs";import{e as A}from"./B4YZClIG.mjs";import{s as C}from"./CXHdal8Z.mjs";import{b as E,s as F,c as G}from"./mb_JAnfe.mjs";import{b as H}from"./BSceNU1G.mjs";import{p as i}from"./CUWjGq9Z.mjs";import{p as I}from"./evd6y-9U.mjs";var J=q('<div role="toolbar"><!></div>');function Y(_,e){j(e,!1);const g=()=>S(I,"$pageTheme",v),[v,h]=W(),l=p(),c=p();let w=i(e,"id",8,void 0),y=i(e,"class",8,""),n=i(e,"size",8,void 0),m=i(e,"wrap",8,void 0),a=p();f(()=>b(n()),()=>{r(l,n()?`--buttons-size: ${n()}rem; `:"")}),f(()=>b(m()),()=>{m()===void 0?r(a,""):r(a,m()?"--buttons-wrap: wrap; ":"--buttons-wrap: nowrap; ")}),f(()=>(s(l),s(a)),()=>{r(c,s(l)+s(a))}),k(),T();var t=J();let u,d;var z=B(t);C(z,e,"default",{}),x(t),D(()=>{var o;E(t,"id",w()),u=F(t,1,`button-toolbar btn-toolbar ${(o=y())!=null?o:""}`,"svelte-1v9a56g",u,{nightMode:g().isDark}),d=G(t,s(c),d,{"--icon-align":"baseline"})}),A("focusout",t,function(o){H.call(this,e,o)}),M(_,t),N(),h()}export{Y as B};
