import"./E-vkuI0X.mjs";import{i as g}from"./DueIe5zz.mjs";import{p as b,e as x,f as k,c as e,d as N,h as R,r as W,b as j,i as m,u as I,j as P}from"./Dpn8_Hnn.mjs";import{s as U}from"./B4YZClIG.mjs";import{i as $}from"./CBivfA5Q.mjs";import{t as n,s as f}from"./X2m-XNKO.mjs";import{s as q}from"./mb_JAnfe.mjs";import{p as l}from"./CUWjGq9Z.mjs";import{w as p}from"./Bfm4T8bX.mjs";import{R as y}from"./Bbw87OuD.mjs";var z=P("<div> </div>");function M(c,t){b(t,!1);let r=l(t,"warning",8),d=l(t,"className",8,"alert-warning");g();var o=x(),v=k(o);{var u=s=>{y(s,{children:(_,A)=>{var a=z(),h=R(a,!0);W(a),j(w=>{var i;q(a,1,`col-12 alert ${(i=d())!=null?i:""} mb-0`),U(h,w)},[()=>(m(p),m(r()),I(()=>p(r())))]),n(1,a,()=>f),n(2,a,()=>f),e(_,a)},$$slots:{default:!0}})};$(v,s=>{r()&&s(u)})}e(c,o),N()}export{M as W};
