import{M as S,a2 as j,a3 as y,a4 as m,g as d,a5 as K,s as N,a6 as U,Z as w,a7 as $,a8 as Z,u as q,a9 as z,aa as C,ab as G,ac as A,ad as J,J as F,ae as H,af as D,ag as g,$ as L,ah as T,ai as p}from"./Dpn8_Hnn.mjs";const Q={get(e,r){if(!e.exclude.includes(r))return d(e.version),r in e.special?e.special[r]():e.props[r]},set(e,r,i){if(!(r in e.special)){var n=w;try{g(e.parent_effect),e.special[r]=W({get[r](){return e.props[r]}},r,m)}finally{g(n)}}return e.special[r](i),D(e.version),!0},getOwnPropertyDescriptor(e,r){if(!e.exclude.includes(r)&&r in e.props)return{enumerable:!0,configurable:!0,value:e.props[r]}},deleteProperty(e,r){return e.exclude.includes(r)||(e.exclude.push(r),D(e.version)),!0},has(e,r){return e.exclude.includes(r)?!1:r in e.props},ownKeys(e){return Reflect.ownKeys(e.props).filter(r=>!e.exclude.includes(r))}};function k(e,r){return new Proxy({props:e,exclude:r,special:{},version:F(0),parent_effect:w},Q)}const V={get(e,r){let i=e.props.length;for(;i--;){let n=e.props[i];if(p(n)&&(n=n()),typeof n=="object"&&n!==null&&r in n)return n[r]}},set(e,r,i){let n=e.props.length;for(;n--;){let s=e.props[n];p(s)&&(s=s());const u=S(s,r);if(u&&u.set)return u.set(i),!0}return!1},getOwnPropertyDescriptor(e,r){let i=e.props.length;for(;i--;){let n=e.props[i];if(p(n)&&(n=n()),typeof n=="object"&&n!==null&&r in n){const s=S(n,r);return s&&!s.configurable&&(s.configurable=!0),s}}},has(e,r){if(r===L||r===T)return!1;for(let i of e.props)if(p(i)&&(i=i()),i!=null&&r in i)return!0;return!1},ownKeys(e){const r=[];for(let i of e.props)if(p(i)&&(i=i()),!!i){for(const n in i)r.includes(n)||r.push(n);for(const n of Object.getOwnPropertySymbols(i))r.includes(n)||r.push(n)}return r}};function ee(...e){return new Proxy({props:e},V)}function W(e,r,i,n){var I,R;var s=!z||(i&C)!==0,u=(i&Z)!==0,O=(i&H)!==0,f=n,P=!0,_=void 0,b=()=>O&&s?(_!=null||(_=A(n)),d(_)):(P&&(P=!1,f=O?q(n):n),f);let l;if(u){var B=L in e||T in e;l=(R=(I=S(e,r))==null?void 0:I.set)!=null?R:B&&r in e?t=>e[r]=t:void 0}var o,x=!1;u?[o,x]=j(()=>e[r]):o=e[r],o===void 0&&n!==void 0&&(o=b(),l&&(s&&y(),l(o)));var a;if(s?a=()=>{var t=e[r];return t===void 0?b():(P=!0,t)}:a=()=>{var t=e[r];return t!==void 0&&(f=void 0),t===void 0?f:t},s&&(i&m)===0)return a;if(l){var M=e.$$legacy;return(function(t,v){return arguments.length>0?((!s||!v||M||x)&&l(v?a():t),t):a()})}var h=!1,c=((i&G)!==0?A:J)(()=>(h=!1,a()));u&&d(c);var Y=w;return(function(t,v){if(arguments.length>0){const E=v?d(c):s&&u?K(t):t;return N(c,E),h=!0,f!==void 0&&(f=E),t}return U&&h||(Y.f&$)!==0?c.v:d(c)})}export{k as l,W as p,ee as s};
