.sticky-container.svelte-123l061{position:sticky;top:var(--sticky-top, 0);bottom:0;left:0;right:0;z-index:var(--z-index, 50);background:var(--sticky-bg, var(--canvas));border-style:solid;border-color:var(--sticky-border, var(--border));border-width:var(--sticky-borders, 0)}
