import{k as H,y as V,ar as fe,as as Y,o as ie,v as le,g as Z,S as se,H as ue,z as $,A as q,V as B,at as oe,au as de,C as j,D as te,av as J,aw as ve,ax as ce,ay as re,ad as pe,az as ge,J as ee,aA as he,aB as _e,m as me,W as Ee,aC as K,aD as T,a7 as we,aE as ae,aF as ne,aG as y,B as Te,aH as Ae,aI as Ce,aJ as Se,aK as Ie,aL as Ne,aM as De,h as Re,r as xe,b as ke,c as He,j as Me}from"./Dpn8_Hnn.mjs";import"./E-vkuI0X.mjs";import"./DueIe5zz.mjs";import{s as be}from"./CXHdal8Z.mjs";import{s as ze}from"./mb_JAnfe.mjs";import{p as Fe}from"./CUWjGq9Z.mjs";function Ue(e,a){return a}function Oe(e,a,s){var g;for(var u=[],c=a.length,i,l=a.length,p=0;p<c;p++){let t=a[p];ne(t,()=>{if(i){if(i.pending.delete(t),i.done.add(t),i.pending.size===0){var h=e.outrogroups;G(e,K(i.done)),h.delete(i),h.size===0&&(e.outrogroups=null)}}else l-=1},!1)}if(l===0){var n=u.length===0&&s!==null;if(n){var o=s,f=o.parentNode;Se(f),f.append(o),e.items.clear()}G(e,a,!n)}else i={pending:new Set(a),done:new Set},((g=e.outrogroups)!=null?g:e.outrogroups=new Set).add(i)}function G(e,a,s=!0){var u;if(e.pending.size>0){u=new Set;for(const l of e.pending.values())for(const p of l)u.add(e.items.get(p).e)}for(var c=0;c<a.length;c++){var i=a[c];if(u!=null&&u.has(i)){i.f|=T;const l=document.createDocumentFragment();Ie(i,l)}else Ne(a[c],s)}}var M;function We(e,a,s,u,c,i=null){var l=e,p=new Map,n=(a&re)!==0;if(n){var o=e;l=H?V(fe(o)):o.appendChild(Y())}H&&ie();var f=null,g=pe(()=>{var v=s();return Ee(v)?v:v==null?[]:K(v)}),t,h=new Map,w=!0;function D(v){(C.effect.f&we)===0&&(C.pending.delete(v),C.fallback=f,Le(C,t,l,a,u),f!==null&&(t.length===0?(f.f&T)===0?ae(f):(f.f^=T,z(f,null,l)):ne(f,()=>{f=null})))}function r(v){C.pending.delete(v)}var d=le(()=>{t=Z(g);var v=t.length;let m=!1;if(H){var F=se(l)===ue;F!==(v===0)&&(l=$(),V(l),q(!1),m=!0)}for(var S=new Set,_=te,x=ce(),I=0;I<v;I+=1){H&&B.nodeType===oe&&B.data===de&&(l=B,m=!0,q(!1));var k=t[I],R=u(k,I),E=w?null:p.get(R);E?(E.v&&j(E.v,k),E.i&&j(E.i,I),x&&_.unskip_effect(E.e)):(E=Be(p,w?l:M!=null?M:M=Y(),k,R,I,c,a,s),w||(E.e.f|=T),p.set(R,E)),S.add(R)}if(v===0&&i&&!f&&(w?f=J(()=>i(l)):(f=J(()=>i(M!=null?M:M=Y())),f.f|=T)),v>S.size&&ve(),H&&v>0&&V($()),!w)if(h.set(_,S),x){for(const[O,L]of p)S.has(O)||_.skip_effect(L.e);_.oncommit(D),_.ondiscard(r)}else D(_);m&&q(!0),Z(g)}),C={effect:d,items:p,pending:h,outrogroups:null,fallback:f};w=!1,H&&(l=B)}function b(e){for(;e!==null&&(e.f&Ae)===0;)e=e.next;return e}function Le(e,a,s,u,c){var k,R,E,O,L,U,W,X,P;var i=(u&Ce)!==0,l=a.length,p=e.items,n=b(e.effect.first),o,f=null,g,t=[],h=[],w,D,r,d;if(i)for(d=0;d<l;d+=1)w=a[d],D=c(w,d),r=p.get(D).e,(r.f&T)===0&&((R=(k=r.nodes)==null?void 0:k.a)==null||R.measure(),(g!=null?g:g=new Set).add(r));for(d=0;d<l;d+=1){if(w=a[d],D=c(w,d),r=p.get(D).e,e.outrogroups!==null)for(const A of e.outrogroups)A.pending.delete(r),A.done.delete(r);if((r.f&y)!==0&&(ae(r),i&&((O=(E=r.nodes)==null?void 0:E.a)==null||O.unfix(),(g!=null?g:g=new Set).delete(r))),(r.f&T)!==0)if(r.f^=T,r===n)z(r,null,s);else{var C=f?f.next:n;r===e.effect.last&&(e.effect.last=r.prev),r.prev&&(r.prev.next=r.next),r.next&&(r.next.prev=r.prev),N(e,f,r),N(e,r,C),z(r,C,s),f=r,t=[],h=[],n=b(f.next);continue}if(r!==n){if(o!==void 0&&o.has(r)){if(t.length<h.length){var v=h[0],m;f=v.prev;var F=t[0],S=t[t.length-1];for(m=0;m<t.length;m+=1)z(t[m],v,s);for(m=0;m<h.length;m+=1)o.delete(h[m]);N(e,F.prev,S.next),N(e,f,F),N(e,S,v),n=v,f=S,d-=1,t=[],h=[]}else o.delete(r),z(r,n,s),N(e,r.prev,r.next),N(e,r,f===null?e.effect.first:f.next),N(e,f,r),f=r;continue}for(t=[],h=[];n!==null&&n!==r;)(o!=null?o:o=new Set).add(n),h.push(n),n=b(n.next);if(n===null)continue}(r.f&T)===0&&t.push(r),f=r,n=b(r.next)}if(e.outrogroups!==null){for(const A of e.outrogroups)A.pending.size===0&&(G(e,K(A.done)),(L=e.outrogroups)==null||L.delete(A));e.outrogroups.size===0&&(e.outrogroups=null)}if(n!==null||o!==void 0){var _=[];if(o!==void 0)for(r of o)(r.f&y)===0&&_.push(r);for(;n!==null;)(n.f&y)===0&&n!==e.fallback&&_.push(n),n=b(n.next);var x=_.length;if(x>0){var I=(u&re)!==0&&l===0?s:null;if(i){for(d=0;d<x;d+=1)(W=(U=_[d].nodes)==null?void 0:U.a)==null||W.measure();for(d=0;d<x;d+=1)(P=(X=_[d].nodes)==null?void 0:X.a)==null||P.fix()}Oe(e,_,I)}}i&&Te(()=>{var A,Q;if(g!==void 0)for(r of g)(Q=(A=r.nodes)==null?void 0:A.a)==null||Q.apply()})}function Be(e,a,s,u,c,i,l,p){var n=(l&he)!==0?(l&_e)===0?me(s,!1,!1):ee(s):null,o=(l&ge)!==0?ee(c):null;return{v:n,i:o,e:J(()=>(i(a,n!=null?n:s,o!=null?o:c,p),()=>{e.delete(u)}))}}function z(e,a,s){if(e.nodes)for(var u=e.nodes.start,c=e.nodes.end,i=a&&(a.f&T)===0?a.nodes.start:s;u!==null;){var l=De(u);if(i.before(u),u===c)return;u=l}}function N(e,a,s){a===null?e.effect.first=s:a.next=s,s===null?e.effect.last=a:s.prev=a}var Ve=Me("<div><!></div>");function Xe(e,a){let s=Fe(a,"class",8,"");var u=Ve(),c=Re(u);be(c,a,"default",{}),xe(u),ke(()=>{var i;return ze(u,1,`row ${(i=s())!=null?i:""}`,"svelte-1owbchr")}),He(e,u)}export{Xe as R,We as e,Ue as i};
