import{k as o,o as c,v as l,R as v,S as b,z as p,y as g,A as f,V as m}from"./Dpn8_Hnn.mjs";import{B as y}from"./Bg0ZbUei.mjs";function E(_,d,h=!1){var n;o&&(n=m,c());var s=new y(_),u=h?v:0;function t(a,r){if(o){var e=b(n);if(a!==parseInt(e.substring(1))){var i=p();g(i),s.anchor=i,f(!1),s.ensure(a,r),f(!0);return}}s.ensure(a,r)}l(()=>{var a=!1;d((r,e=0)=>{a=!0,t(e,r)}),a||t(-1,null)},u)}export{E as i};
