import{o as _,I as w}from"./C02ceTqP.mjs";import"./E-vkuI0X.mjs";import{i as M}from"./DueIe5zz.mjs";import{c as I,o as k}from"./Bg0ZbUei.mjs";import{p as z,h as C,e as E,f as S,c as u,r as X,b as x,d as y,j as B,g as d,s as P,m as j}from"./Dpn8_Hnn.mjs";import{e as m}from"./B4YZClIG.mjs";import{s as D}from"./CXHdal8Z.mjs";import{b as H,s as N}from"./mb_JAnfe.mjs";import{b as O}from"./BpPdjRFB.mjs";import{b as c}from"./BSceNU1G.mjs";import{p as i}from"./CUWjGq9Z.mjs";function Y(o){throw new Error(`unreachable: ${o}`)}function Z(...o){return()=>{for(const t of o)t()}}function $(o){let t=!1;function r(s){t=s}const n=_(document,"keydown",s=>{s.key==="Escape"&&t&&(s.stopImmediatePropagation(),o&&o())},{capture:!0});return{set:r,remove:n}}var R=B('<button tabindex="-1"><!></button>');function tt(o,t){z(t,!1);let r=i(t,"class",8,""),n=i(t,"tooltip",8,void 0),s=i(t,"iconSize",8,100),p=i(t,"widthMultiplier",8,1),b=i(t,"flipX",8,!1);const h=I();let l=j();k(()=>{h("mount",{span:d(l)})}),M();var a=R(),g=C(a);w(g,{get iconSize(){return s()},get widthMultiplier(){return p()},get flipX(){return b()},children:(e,U)=>{var f=E(),v=S(f);D(v,t,"default",{}),u(e,f)},$$slots:{default:!0}}),X(a),O(a,e=>P(l,e),()=>d(l)),x(()=>{var e;H(a,"title",n()),N(a,1,`badge ${(e=r())!=null?e:""}`,"svelte-1fmrmgo")}),m("click",a,function(e){c.call(this,t,e)}),m("mouseenter",a,function(e){c.call(this,t,e)}),m("mouseleave",a,function(e){c.call(this,t,e)}),u(o,a),y()}export{tt as B,Y as a,$ as r,Z as s};
