import"./E-vkuI0X.mjs";import"./DueIe5zz.mjs";import{h as z,e as M,f as S,c as n,r as X,b as x,j}from"./Dpn8_Hnn.mjs";import{e as s}from"./B4YZClIG.mjs";import{s as k}from"./CXHdal8Z.mjs";import{b as l,s as B}from"./mb_JAnfe.mjs";import{p as C}from"./CcCPeAdh.mjs";import{b as f}from"./BSceNU1G.mjs";import{p as i}from"./CUWjGq9Z.mjs";import{I as D}from"./C02ceTqP.mjs";var N=j("<button><!></button>");function Q(m,t){let c=i(t,"id",8,void 0),d=i(t,"class",8,""),u=i(t,"tooltip",8,void 0),b=i(t,"primary",8,!1),v=i(t,"active",8,!1),h=i(t,"disabled",8,!1),p=i(t,"tabbable",8,!1),_=i(t,"iconSize",8,75),g=i(t,"widthMultiplier",8,1),w=i(t,"flipX",8,!1);var e=N();let r;var I=z(e);D(I,{get flipX(){return w()},get widthMultiplier(){return g()},get iconSize(){return _()},children:(a,P)=>{var o=M(),y=S(o);k(y,t,"default",{}),n(a,o)},$$slots:{default:!0}}),X(e),x(()=>{var a;l(e,"id",c()),r=B(e,1,`icon-button ${(a=d())!=null?a:""}`,"svelte-9egv84",r,{active:v(),primary:b()}),l(e,"title",u()),e.disabled=h(),l(e,"tabindex",p()?0:-1)}),s("click",e,function(a){f.call(this,t,a)}),s("mousedown",e,C(function(a){f.call(this,t,a)})),n(m,e)}export{Q as I};
