import"./E-vkuI0X.mjs";import{i as lt}from"./DueIe5zz.mjs";import{o as dt,a as ct}from"./Bg0ZbUei.mjs";import{p as ht,ba as ut,h as z,al as $,r as G,s as mt,g as C,b as _t,c as pt,d as ft,m as gt,j as bt}from"./Dpn8_Hnn.mjs";import{s as U}from"./CXHdal8Z.mjs";import{s as Et}from"./mb_JAnfe.mjs";import{b as O}from"./rMiotwLk.mjs";import{b as kt}from"./BpPdjRFB.mjs";import{p as D}from"./CUWjGq9Z.mjs";import{a as wt}from"./_d1bhYXs.mjs";import{r as F,a as tt,b as K,e as W,d as At,c as vt}from"./DNxMDov_.mjs";import{r as Tt}from"./BYPCfOl0.mjs";import{m as yt}from"./BgNze5Q0.mjs";const Zt={DeckOptions:{maximumInterval:"https://docs.ankiweb.net/deck-options.html#maximum-interval",startingEase:"https://docs.ankiweb.net/deck-options.html#starting-ease",easyBonus:"https://docs.ankiweb.net/deck-options.html#easy-bonus",intervalModifier:"https://docs.ankiweb.net/deck-options.html#interval-modifier",hardInterval:"https://docs.ankiweb.net/deck-options.html#hard-interval",newInterval:"https://docs.ankiweb.net/deck-options.html#new-interval",advanced:"https://docs.ankiweb.net/deck-options.html#advanced",timer:"https://docs.ankiweb.net/deck-options.html#timers",autoAdvance:"https://docs.ankiweb.net/deck-options.html#auto-advance",learningSteps:"https://docs.ankiweb.net/deck-options.html#learning-steps",graduatingInterval:"https://docs.ankiweb.net/deck-options.html#graduating-interval",easyInterval:"https://docs.ankiweb.net/deck-options.html#easy-interval",insertionOrder:"https://docs.ankiweb.net/deck-options.html#insertion-order",newCards:"https://docs.ankiweb.net/deck-options.html#new-cards",relearningSteps:"https://docs.ankiweb.net/deck-options.html#relearning-steps",minimumInterval:"https://docs.ankiweb.net/deck-options.html#minimum-interval",lapses:"https://docs.ankiweb.net/deck-options.html#lapses",displayOrder:"https://docs.ankiweb.net/deck-options.html#display-order",maximumReviewsday:"https://docs.ankiweb.net/deck-options.html#maximum-reviewsday",newCardsday:"https://docs.ankiweb.net/deck-options.html#new-cardsday",limitsFromTop:"https://docs.ankiweb.net/deck-options.html#limits-start-from-top",dailyLimits:"https://docs.ankiweb.net/deck-options.html#daily-limits",audio:"https://docs.ankiweb.net/deck-options.html#audio",fsrs:"https://docs.ankiweb.net/deck-options.html#fsrs",desiredRetention:"https://docs.ankiweb.net/deck-options.html#desired-retention"},Leeches:{leeches:"https://docs.ankiweb.net/leeches.html#leeches",waiting:"https://docs.ankiweb.net/leeches.html#waiting"},Studying:{siblingsAndBurying:"https://docs.ankiweb.net/studying.html#siblings-and-burying"},PackageImporting:{root:"https://docs.ankiweb.net/importing/packaged-decks.html",updating:"https://docs.ankiweb.net/importing/packaged-decks.html#updating",scheduling:"https://docs.ankiweb.net/importing/packaged-decks.html#scheduling"},TextImporting:{root:"https://docs.ankiweb.net/importing/text-files.html",updating:"https://docs.ankiweb.net/importing/text-files.html#duplicates-and-updating",html:"https://docs.ankiweb.net/importing/text-files.html#html"},Editing:{adding:"https://docs.ankiweb.net/editing.html#adding-cards-and-notes"}};var R={exports:{}},V={exports:{}};/*!
  * Bootstrap backdrop.js v5.3.8 (https://getbootstrap.com/)
  * Copyright 2011-2025 The Bootstrap Authors (https://github.com/twbs/bootstrap/graphs/contributors)
  * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
  */var Ct=V.exports,Q;function Dt(){return Q||(Q=1,(function(w,a){(function(o,i){w.exports=i(F(),tt(),K())})(Ct,(function(o,i,r){const f="backdrop",g="fade",l="show",u=`mousedown.bs.${f}`,m={className:"modal-backdrop",clickCallback:null,isAnimated:!1,isVisible:!0,rootElement:"body"},_={className:"string",clickCallback:"(function|null)",isAnimated:"boolean",isVisible:"boolean",rootElement:"(element|string)"};class s extends i{constructor(e){super(),this._config=this._getConfig(e),this._isAppended=!1,this._element=null}static get Default(){return m}static get DefaultType(){return _}static get NAME(){return f}show(e){if(!this._config.isVisible){r.execute(e);return}this._append();const p=this._getElement();this._config.isAnimated&&r.reflow(p),p.classList.add(l),this._emulateAnimation(()=>{r.execute(e)})}hide(e){if(!this._config.isVisible){r.execute(e);return}this._getElement().classList.remove(l),this._emulateAnimation(()=>{this.dispose(),r.execute(e)})}dispose(){this._isAppended&&(o.off(this._element,u),this._element.remove(),this._isAppended=!1)}_getElement(){if(!this._element){const e=document.createElement("div");e.className=this._config.className,this._config.isAnimated&&e.classList.add(g),this._element=e}return this._element}_configAfterMerge(e){return e.rootElement=r.getElement(e.rootElement),e}_append(){if(this._isAppended)return;const e=this._getElement();this._config.rootElement.append(e),o.on(e,u,()=>{r.execute(this._config.clickCallback)}),this._isAppended=!0}_emulateAnimation(e){r.executeAfterTransition(e,this._getElement(),this._config.isAnimated)}}return s}))})(V)),V.exports}var L={exports:{}};/*!
  * Bootstrap component-functions.js v5.3.8 (https://getbootstrap.com/)
  * Copyright 2011-2025 The Bootstrap Authors (https://github.com/twbs/bootstrap/graphs/contributors)
  * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
  */var Nt=L.exports,J;function St(){return J||(J=1,(function(w,a){(function(o,i){i(a,F(),W(),K())})(Nt,(function(o,i,r,f){const g=(l,u="hide")=>{const m=`click.dismiss${l.EVENT_KEY}`,_=l.NAME;i.on(document,m,`[data-bs-dismiss="${_}"]`,function(s){if(["A","AREA"].includes(this.tagName)&&s.preventDefault(),f.isDisabled(this))return;const t=r.getElementFromSelector(this)||this.closest(`.${_}`);l.getOrCreateInstance(t)[u]()})};o.enableDismissTrigger=g,Object.defineProperty(o,Symbol.toStringTag,{value:"Module"})}))})(L,L.exports)),L.exports}var B={exports:{}};/*!
  * Bootstrap focustrap.js v5.3.8 (https://getbootstrap.com/)
  * Copyright 2011-2025 The Bootstrap Authors (https://github.com/twbs/bootstrap/graphs/contributors)
  * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
  */var xt=B.exports,X;function Ot(){return X||(X=1,(function(w,a){(function(o,i){w.exports=i(F(),W(),tt())})(xt,(function(o,i,r){const f="focustrap",l=".bs.focustrap",u=`focusin${l}`,m=`keydown.tab${l}`,_="Tab",s="forward",t="backward",e={autofocus:!0,trapElement:null},p={autofocus:"boolean",trapElement:"element"};class b extends r{constructor(d){super(),this._config=this._getConfig(d),this._isActive=!1,this._lastTabNavDirection=null}static get Default(){return e}static get DefaultType(){return p}static get NAME(){return f}activate(){this._isActive||(this._config.autofocus&&this._config.trapElement.focus(),o.off(document,l),o.on(document,u,d=>this._handleFocusin(d)),o.on(document,m,d=>this._handleKeydown(d)),this._isActive=!0)}deactivate(){this._isActive&&(this._isActive=!1,o.off(document,l))}_handleFocusin(d){const{trapElement:A}=this._config;if(d.target===document||d.target===A||A.contains(d.target))return;const v=i.focusableChildren(A);v.length===0?A.focus():this._lastTabNavDirection===t?v[v.length-1].focus():v[0].focus()}_handleKeydown(d){d.key===_&&(this._lastTabNavDirection=d.shiftKey?t:s)}}return b}))})(B)),B.exports}var q={exports:{}};/*!
  * Bootstrap scrollbar.js v5.3.8 (https://getbootstrap.com/)
  * Copyright 2011-2025 The Bootstrap Authors (https://github.com/twbs/bootstrap/graphs/contributors)
  * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
  */var Lt=q.exports,Z;function Mt(){return Z||(Z=1,(function(w,a){(function(o,i){w.exports=i(At(),W(),K())})(Lt,(function(o,i,r){const f=".fixed-top, .fixed-bottom, .is-fixed, .sticky-top",g=".sticky-top",l="padding-right",u="margin-right";class m{constructor(){this._element=document.body}getWidth(){const s=document.documentElement.clientWidth;return Math.abs(window.innerWidth-s)}hide(){const s=this.getWidth();this._disableOverFlow(),this._setElementAttributes(this._element,l,t=>t+s),this._setElementAttributes(f,l,t=>t+s),this._setElementAttributes(g,u,t=>t-s)}reset(){this._resetElementAttributes(this._element,"overflow"),this._resetElementAttributes(this._element,l),this._resetElementAttributes(f,l),this._resetElementAttributes(g,u)}isOverflowing(){return this.getWidth()>0}_disableOverFlow(){this._saveInitialAttribute(this._element,"overflow"),this._element.style.overflow="hidden"}_setElementAttributes(s,t,e){const p=this.getWidth(),b=E=>{if(E!==this._element&&window.innerWidth>E.clientWidth+p)return;this._saveInitialAttribute(E,t);const d=window.getComputedStyle(E).getPropertyValue(t);E.style.setProperty(t,`${e(Number.parseFloat(d))}px`)};this._applyManipulationCallback(s,b)}_saveInitialAttribute(s,t){const e=s.style.getPropertyValue(t);e&&o.setDataAttribute(s,t,e)}_resetElementAttributes(s,t){const e=p=>{const b=o.getDataAttribute(p,t);if(b===null){p.style.removeProperty(t);return}o.removeDataAttribute(p,t),p.style.setProperty(t,b)};this._applyManipulationCallback(s,e)}_applyManipulationCallback(s,t){if(r.isElement(s)){t(s);return}for(const e of i.find(s,this._element))t(e)}}return m}))})(q)),q.exports}/*!
  * Bootstrap modal.js v5.3.8 (https://getbootstrap.com/)
  * Copyright 2011-2025 The Bootstrap Authors (https://github.com/twbs/bootstrap/graphs/contributors)
  * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
  */var It=R.exports,j;function Rt(){return j||(j=1,(function(w,a){(function(o,i){w.exports=i(vt(),F(),W(),Dt(),St(),Ot(),K(),Mt())})(It,(function(o,i,r,f,g,l,u,m){const _="modal",t=".bs.modal",e=".data-api",p="Escape",b=`hide${t}`,E=`hidePrevented${t}`,d=`hidden${t}`,A=`show${t}`,v=`shown${t}`,Y=`resize${t}`,y=`click.dismiss${t}`,N=`mousedown.dismiss${t}`,M=`keydown.dismiss${t}`,I=`click${t}${e}`,S="modal-open",P="fade",c="show",H="modal-static",et=".modal.show",it=".modal-dialog",st=".modal-body",nt='[data-bs-toggle="modal"]',ot={backdrop:!0,focus:!0,keyboard:!0},at={backdrop:"(boolean|string)",focus:"boolean",keyboard:"boolean"};class T extends o{constructor(n,h){super(n,h),this._dialog=r.findOne(it,this._element),this._backdrop=this._initializeBackDrop(),this._focustrap=this._initializeFocusTrap(),this._isShown=!1,this._isTransitioning=!1,this._scrollBar=new m,this._addEventListeners()}static get Default(){return ot}static get DefaultType(){return at}static get NAME(){return _}toggle(n){return this._isShown?this.hide():this.show(n)}show(n){this._isShown||this._isTransitioning||i.trigger(this._element,A,{relatedTarget:n}).defaultPrevented||(this._isShown=!0,this._isTransitioning=!0,this._scrollBar.hide(),document.body.classList.add(S),this._adjustDialog(),this._backdrop.show(()=>this._showElement(n)))}hide(){!this._isShown||this._isTransitioning||i.trigger(this._element,b).defaultPrevented||(this._isShown=!1,this._isTransitioning=!0,this._focustrap.deactivate(),this._element.classList.remove(c),this._queueCallback(()=>this._hideModal(),this._element,this._isAnimated()))}dispose(){i.off(window,t),i.off(this._dialog,t),this._backdrop.dispose(),this._focustrap.deactivate(),super.dispose()}handleUpdate(){this._adjustDialog()}_initializeBackDrop(){return new f({isVisible:!!this._config.backdrop,isAnimated:this._isAnimated()})}_initializeFocusTrap(){return new l({trapElement:this._element})}_showElement(n){document.body.contains(this._element)||document.body.append(this._element),this._element.style.display="block",this._element.removeAttribute("aria-hidden"),this._element.setAttribute("aria-modal",!0),this._element.setAttribute("role","dialog"),this._element.scrollTop=0;const h=r.findOne(st,this._dialog);h&&(h.scrollTop=0),u.reflow(this._element),this._element.classList.add(c);const k=()=>{this._config.focus&&this._focustrap.activate(),this._isTransitioning=!1,i.trigger(this._element,v,{relatedTarget:n})};this._queueCallback(k,this._dialog,this._isAnimated())}_addEventListeners(){i.on(this._element,M,n=>{if(n.key===p){if(this._config.keyboard){this.hide();return}this._triggerBackdropTransition()}}),i.on(window,Y,()=>{this._isShown&&!this._isTransitioning&&this._adjustDialog()}),i.on(this._element,N,n=>{i.one(this._element,y,h=>{if(!(this._element!==n.target||this._element!==h.target)){if(this._config.backdrop==="static"){this._triggerBackdropTransition();return}this._config.backdrop&&this.hide()}})})}_hideModal(){this._element.style.display="none",this._element.setAttribute("aria-hidden",!0),this._element.removeAttribute("aria-modal"),this._element.removeAttribute("role"),this._isTransitioning=!1,this._backdrop.hide(()=>{document.body.classList.remove(S),this._resetAdjustments(),this._scrollBar.reset(),i.trigger(this._element,d)})}_isAnimated(){return this._element.classList.contains(P)}_triggerBackdropTransition(){if(i.trigger(this._element,E).defaultPrevented)return;const h=this._element.scrollHeight>document.documentElement.clientHeight,k=this._element.style.overflowY;k==="hidden"||this._element.classList.contains(H)||(h||(this._element.style.overflowY="hidden"),this._element.classList.add(H),this._queueCallback(()=>{this._element.classList.remove(H),this._queueCallback(()=>{this._element.style.overflowY=k},this._dialog)},this._dialog),this._element.focus())}_adjustDialog(){const n=this._element.scrollHeight>document.documentElement.clientHeight,h=this._scrollBar.getWidth(),k=h>0;if(k&&!n){const x=u.isRTL()?"paddingLeft":"paddingRight";this._element.style[x]=`${h}px`}if(!k&&n){const x=u.isRTL()?"paddingRight":"paddingLeft";this._element.style[x]=`${h}px`}}_resetAdjustments(){this._element.style.paddingLeft="",this._element.style.paddingRight=""}static jQueryInterface(n,h){return this.each(function(){const k=T.getOrCreateInstance(this,n);if(typeof n=="string"){if(typeof k[n]>"u")throw new TypeError(`No method named "${n}"`);k[n](h)}})}}return i.on(document,I,nt,function(rt){const n=r.getElementFromSelector(this);["A","AREA"].includes(this.tagName)&&rt.preventDefault(),i.one(n,A,x=>{x.defaultPrevented||i.one(n,d,()=>{u.isVisible(this)&&this.focus()})});const h=r.findOne(et);h&&T.getInstance(h).hide(),T.getOrCreateInstance(n).toggle(this)}),g.enableDismissTrigger(T),u.defineJQueryPlugin(T),T}))})(R)),R.exports}var Vt=Rt();const Bt=wt(Vt);var qt=bt('<div class="modal fade svelte-1bxxfaq" tabindex="-1" aria-labelledby="modalLabel" aria-hidden="true"><div><div class="modal-content svelte-1bxxfaq"><!> <!> <!></div></div></div>');function jt(w,a){ht(a,!1);let o=D(a,"modalKey",24,()=>Math.random().toString(36).substring(2)),i=D(a,"dialogClass",8,""),r=D(a,"onOkClicked",8,void 0),f=D(a,"onCancelClicked",8,void 0),g=D(a,"onShown",8,void 0),l=D(a,"onHidden",8,void 0);const u=ut(yt);let m,_=gt();function s(){var c;m.hide(),(c=r())==null||c()}function t(){var c;m.hide(),(c=f())==null||c()}function e(){m.show()}function p(){m.hide()}function b(){m.toggle()}const{set:E,remove:d}=Tt(s);function A(){var c;E(!0),(c=g())==null||c()}function v(){var c;E(!1),(c=l())==null||c()}dt(()=>{C(_).addEventListener("shown.bs.modal",A),C(_).addEventListener("hidden.bs.modal",v),m=new Bt(C(_),{keyboard:!1}),u.set(o(),m)}),ct(()=>{d(),C(_).removeEventListener("shown.bs.modal",A),C(_).removeEventListener("hidden.bs.modal",v)});var Y={show:e,hide:p,toggle:b,acceptHandler:s,cancelHandler:t};lt();var y=qt(),N=z(y),M=z(N),I=z(M);U(I,a,"header",{});var S=$(I,2);U(S,a,"body",{});var P=$(S,2);return U(P,a,"footer",{}),G(M),G(N),G(y),kt(y,c=>mt(_,c),()=>C(_)),_t(()=>{var c;return Et(N,1,`modal-dialog ${(c=i())!=null?c:""}`,"svelte-1bxxfaq")}),pt(w,y),O(a,"show",e),O(a,"hide",p),O(a,"toggle",b),O(a,"acceptHandler",s),O(a,"cancelHandler",t),ft(Y)}export{Zt as H,jt as M,Bt as a};
