.revert.svelte-1pfrxat{position:absolute;right:-1.7em;bottom:-1px;color:var(--fg-faint)}.revert.rtl.svelte-1pfrxat{right:unset;left:-1.7em}.config-input.svelte-1pfrxat:hover .revert:where(.svelte-1pfrxat),.config-input.svelte-1pfrxat:focus-within .revert:where(.svelte-1pfrxat){color:var(--fg-subtle)}.config-input.svelte-1pfrxat .revert:where(.svelte-1pfrxat):hover{color:var(--fg)}.badge{cursor:pointer}.hide.svelte-hl2p3x .badge{display:none;cursor:initial}.setting-title.svelte-fly1c9{cursor:help}.setting-title.svelte-fly1c9:hover{text-decoration:underline dotted var(--fg-subtle)}label.svelte-17f4zrl{display:inline}
