import"./E-vkuI0X.mjs";import"./DueIe5zz.mjs";import{h as i,r as p,b as x,c as d,j as f}from"./Dpn8_Hnn.mjs";import{s as v}from"./CXHdal8Z.mjs";import{s as n}from"./mb_JAnfe.mjs";import{p as e}from"./CUWjGq9Z.mjs";var b=f("<div><!></div>");function j(r,o){let m=e(o,"class",8,""),l=e(o,"breakpoint",8,"xs");var s=b();let t;var c=i(s);v(c,o,"default",{}),p(s),x(()=>{var a;return t=n(s,1,`col ${(a=m())!=null?a:""}`,"svelte-c0c30t",t,{"col-xs":l()==="xs","col-sm":l()==="sm","col-md":l()==="md","col-lg":l()==="lg","col-xl":l()==="xl","col-xxl":l()==="xxl"})}),d(r,s)}export{j as C};
