import"./E-vkuI0X.mjs";import{i as w}from"./DueIe5zz.mjs";import{c as x,o as D}from"./Bg0ZbUei.mjs";import{p as L,h as j,r as k,b as q,c as B,d as E,j as M,g as m,s as N,m as R}from"./Dpn8_Hnn.mjs";import{e as n}from"./B4YZClIG.mjs";import{s as z}from"./CXHdal8Z.mjs";import{b as i,s as A}from"./mb_JAnfe.mjs";import{b as C}from"./BpPdjRFB.mjs";import{p as F}from"./CcCPeAdh.mjs";import{b as r}from"./BSceNU1G.mjs";import{p as s}from"./CUWjGq9Z.mjs";var G=M("<button><!></button>");function W(b,t){L(t,!1);let f=s(t,"id",8,void 0),c=s(t,"class",8,""),d=s(t,"primary",8,!1),u=s(t,"tooltip",8,void 0),p=s(t,"active",8,!1),v=s(t,"disabled",8,!1),h=s(t,"tabbable",8,!1),_=s(t,"ellipsis",8,!1),l=R();const y=x();D(()=>y("mount",{button:m(l)})),w();var e=G();let o;var g=j(e);z(g,t,"default",{}),k(e),C(e,a=>N(l,a),()=>m(l)),q(()=>{var a;i(e,"id",f()),o=A(e,1,`label-button ${(a=c())!=null?a:""}`,"svelte-qwvah",o,{active:p(),primary:d(),ellipsis:_()}),i(e,"title",u()),e.disabled=v(),i(e,"tabindex",h()?0:-1)}),n("click",e,function(a){r.call(this,t,a)}),n("mousedown",e,F(function(a){r.call(this,t,a)})),B(b,e),E()}export{W as L};
