# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: anki/frontend.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'anki/frontend.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from anki import scheduler_pb2 as anki_dot_scheduler__pb2
from anki import generic_pb2 as anki_dot_generic__pb2
from anki import search_pb2 as anki_dot_search__pb2
from anki import notes_pb2 as anki_dot_notes__pb2
from anki import notetypes_pb2 as anki_dot_notetypes__pb2
from anki import links_pb2 as anki_dot_links__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x61nki/frontend.proto\x12\ranki.frontend\x1a\x14\x61nki/scheduler.proto\x1a\x12\x61nki/generic.proto\x1a\x11\x61nki/search.proto\x1a\x10\x61nki/notes.proto\x1a\x14\x61nki/notetypes.proto\x1a\x10\x61nki/links.proto\"\x83\x01\n\x1bSchedulingStatesWithContext\x12\x30\n\x06states\x18\x01 \x01(\x0b\x32 .anki.scheduler.SchedulingStates\x12\x32\n\x07\x63ontext\x18\x02 \x01(\x0b\x32!.anki.scheduler.SchedulingContext\"[\n\x1aSetSchedulingStatesRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x30\n\x06states\x18\x02 \x01(\x0b\x32 .anki.scheduler.SchedulingStates\"6\n\x19\x43onvertPastedImageRequest\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0b\n\x03\x65xt\x18\x02 \x01(\t\"*\n\x1a\x43onvertPastedImageResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"8\n\x15SetSettingJsonRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\nvalue_json\x18\x02 \x01(\x0c\"c\n\x15openFilePickerRequest\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x1a\n\x12\x66ilter_description\x18\x03 \x01(\t\x12\x12\n\nextensions\x18\x04 \x03(\t\"%\n\x14ReadClipboardRequest\x12\r\n\x05types\x18\x01 \x03(\t\"\x82\x01\n\x15ReadClipboardResponse\x12<\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32..anki.frontend.ReadClipboardResponse.DataEntry\x1a+\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x82\x01\n\x15WriteClipboardRequest\x12<\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32..anki.frontend.WriteClipboardRequest.DataEntry\x1a+\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"c\n\x04Help\x12=\n\thelp_page\x18\x01 \x01(\x0e\x32(.anki.links.HelpPageLinkRequest.HelpPageH\x00\x12\x13\n\thelp_link\x18\x02 \x01(\tH\x00\x42\x07\n\x05value\"\x95\x01\n\x0e\x41skUserRequest\x12\x0c\n\x04text\x18\x01 \x01(\t\x12&\n\x04help\x18\x02 \x01(\x0b\x32\x13.anki.frontend.HelpH\x00\x88\x01\x01\x12\x12\n\x05title\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x17\n\ndefault_no\x18\x05 \x01(\x08H\x02\x88\x01\x01\x42\x07\n\x05_helpB\x08\n\x06_titleB\r\n\x0b_default_no\"\xcb\x01\n\x15ShowMessageBoxRequest\x12\x0c\n\x04text\x18\x01 \x01(\t\x12+\n\x04type\x18\x02 \x01(\x0e\x32\x1d.anki.frontend.MessageBoxType\x12&\n\x04help\x18\x03 \x01(\x0b\x32\x13.anki.frontend.HelpH\x00\x88\x01\x01\x12\x12\n\x05title\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0btext_format\x18\x05 \x01(\tH\x02\x88\x01\x01\x42\x07\n\x05_helpB\x08\n\x06_titleB\x0e\n\x0c_text_format*5\n\x0eMessageBoxType\x12\x08\n\x04INFO\x10\x00\x12\x0b\n\x07WARNING\x10\x01\x12\x0c\n\x08\x43RITICAL\x10\x02\x32\xe7\r\n\x0f\x46rontendService\x12\x61\n\x1eGetSchedulingStatesWithContext\x12\x13.anki.generic.Empty\x1a*.anki.frontend.SchedulingStatesWithContext\x12U\n\x13SetSchedulingStates\x12).anki.frontend.SetSchedulingStatesRequest\x1a\x13.anki.generic.Empty\x12\x36\n\nImportDone\x12\x13.anki.generic.Empty\x1a\x13.anki.generic.Empty\x12?\n\x0fSearchInBrowser\x12\x17.anki.search.SearchNode\x1a\x13.anki.generic.Empty\x12\x43\n\x17\x64\x65\x63kOptionsRequireClose\x12\x13.anki.generic.Empty\x1a\x13.anki.generic.Empty\x12<\n\x10\x64\x65\x63kOptionsReady\x12\x13.anki.generic.Empty\x1a\x13.anki.generic.Empty\x12i\n\x12\x43onvertPastedImage\x12(.anki.frontend.ConvertPastedImageRequest\x1a).anki.frontend.ConvertPastedImageResponse\x12L\n\x0eOpenFilePicker\x12$.anki.frontend.openFilePickerRequest\x1a\x14.anki.generic.String\x12\x36\n\tOpenMedia\x12\x14.anki.generic.String\x1a\x13.anki.generic.Empty\x12>\n\x11ShowInMediaFolder\x12\x14.anki.generic.String\x1a\x13.anki.generic.Empty\x12\x38\n\x0bRecordAudio\x12\x13.anki.generic.Empty\x1a\x14.anki.generic.String\x12\x38\n\rCloseAddCards\x12\x12.anki.generic.Bool\x1a\x13.anki.generic.Empty\x12<\n\x10\x43loseEditCurrent\x12\x13.anki.generic.Empty\x1a\x13.anki.generic.Empty\x12\x35\n\x08OpenLink\x12\x14.anki.generic.String\x1a\x13.anki.generic.Empty\x12<\n\x07\x41skUser\x12\x1d.anki.frontend.AskUserRequest\x1a\x12.anki.generic.Bool\x12K\n\x0eShowMessageBox\x12$.anki.frontend.ShowMessageBoxRequest\x1a\x13.anki.generic.Empty\x12<\n\x10OpenFieldsDialog\x12\x13.anki.generic.Empty\x1a\x13.anki.generic.Empty\x12;\n\x0fOpenCardsDialog\x12\x13.anki.generic.Empty\x1a\x13.anki.generic.Empty\x12@\n\x14GetProfileConfigJson\x12\x14.anki.generic.String\x1a\x12.anki.generic.Json\x12Q\n\x14SetProfileConfigJson\x12$.anki.frontend.SetSettingJsonRequest\x1a\x13.anki.generic.Empty\x12\x37\n\x0bGetMetaJson\x12\x14.anki.generic.String\x1a\x12.anki.generic.Json\x12H\n\x0bSetMetaJson\x12$.anki.frontend.SetSettingJsonRequest\x1a\x13.anki.generic.Empty\x12Z\n\rReadClipboard\x12#.anki.frontend.ReadClipboardRequest\x1a$.anki.frontend.ReadClipboardResponse\x12K\n\x0eWriteClipboard\x12$.anki.frontend.WriteClipboardRequest\x1a\x13.anki.generic.Empty\x12=\n\x11SaveCustomColours\x12\x13.anki.generic.Empty\x1a\x13.anki.generic.Empty2\x18\n\x16\x42\x61\x63kendFrontendServiceB\x02P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'anki.frontend_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'P\001'
  _globals['_READCLIPBOARDRESPONSE_DATAENTRY']._loaded_options = None
  _globals['_READCLIPBOARDRESPONSE_DATAENTRY']._serialized_options = b'8\001'
  _globals['_WRITECLIPBOARDREQUEST_DATAENTRY']._loaded_options = None
  _globals['_WRITECLIPBOARDREQUEST_DATAENTRY']._serialized_options = b'8\001'
  _globals['_MESSAGEBOXTYPE']._serialized_start=1407
  _globals['_MESSAGEBOXTYPE']._serialized_end=1460
  _globals['_SCHEDULINGSTATESWITHCONTEXT']._serialized_start=158
  _globals['_SCHEDULINGSTATESWITHCONTEXT']._serialized_end=289
  _globals['_SETSCHEDULINGSTATESREQUEST']._serialized_start=291
  _globals['_SETSCHEDULINGSTATESREQUEST']._serialized_end=382
  _globals['_CONVERTPASTEDIMAGEREQUEST']._serialized_start=384
  _globals['_CONVERTPASTEDIMAGEREQUEST']._serialized_end=438
  _globals['_CONVERTPASTEDIMAGERESPONSE']._serialized_start=440
  _globals['_CONVERTPASTEDIMAGERESPONSE']._serialized_end=482
  _globals['_SETSETTINGJSONREQUEST']._serialized_start=484
  _globals['_SETSETTINGJSONREQUEST']._serialized_end=540
  _globals['_OPENFILEPICKERREQUEST']._serialized_start=542
  _globals['_OPENFILEPICKERREQUEST']._serialized_end=641
  _globals['_READCLIPBOARDREQUEST']._serialized_start=643
  _globals['_READCLIPBOARDREQUEST']._serialized_end=680
  _globals['_READCLIPBOARDRESPONSE']._serialized_start=683
  _globals['_READCLIPBOARDRESPONSE']._serialized_end=813
  _globals['_READCLIPBOARDRESPONSE_DATAENTRY']._serialized_start=770
  _globals['_READCLIPBOARDRESPONSE_DATAENTRY']._serialized_end=813
  _globals['_WRITECLIPBOARDREQUEST']._serialized_start=816
  _globals['_WRITECLIPBOARDREQUEST']._serialized_end=946
  _globals['_WRITECLIPBOARDREQUEST_DATAENTRY']._serialized_start=770
  _globals['_WRITECLIPBOARDREQUEST_DATAENTRY']._serialized_end=813
  _globals['_HELP']._serialized_start=948
  _globals['_HELP']._serialized_end=1047
  _globals['_ASKUSERREQUEST']._serialized_start=1050
  _globals['_ASKUSERREQUEST']._serialized_end=1199
  _globals['_SHOWMESSAGEBOXREQUEST']._serialized_start=1202
  _globals['_SHOWMESSAGEBOXREQUEST']._serialized_end=1405
  _globals['_FRONTENDSERVICE']._serialized_start=1463
  _globals['_FRONTENDSERVICE']._serialized_end=3230
  _globals['_BACKENDFRONTENDSERVICE']._serialized_start=3232
  _globals['_BACKENDFRONTENDSERVICE']._serialized_end=3256
# @@protoc_insertion_point(module_scope)
