import"./E-vkuI0X.mjs";import"./DueIe5zz.mjs";import{p as v,l as n,s as r,i as m,g as s,a as w,h,r as z,b as y,c as B,d as j,m as u,j as x}from"./Dpn8_Hnn.mjs";import{s as G}from"./CXHdal8Z.mjs";import{b as N,s as S,c as W}from"./mb_JAnfe.mjs";import{p as o}from"./CUWjGq9Z.mjs";var k=x('<div dir="ltr" role="group"><!></div>');function H(c,t){v(t,!1);const i=u(),p=u();let _=o(t,"id",8,void 0),b=o(t,"class",8,""),d=o(t,"size",8,void 0),l=o(t,"wrap",8,void 0),a=u();n(()=>m(d()),()=>{r(i,d()?`--buttons-size: ${d()}rem; `:"")}),n(()=>m(l()),()=>{l()===void 0?r(a,""):r(a,l()?"--buttons-wrap: wrap; ":"--buttons-wrap: nowrap; ")}),n(()=>(s(i),s(a)),()=>{r(p,s(i)+s(a))}),w();var e=k(),g=h(e);G(g,t,"default",{}),z(e),y(()=>{var f;N(e,"id",_()),S(e,1,`button-group btn-group ${(f=b())!=null?f:""}`,"svelte-1huz2aw"),W(e,s(p)),e.dir=e.dir}),B(c,e),j()}export{H as B};
