const o=Symbol("touchDevice"),e=Symbol("section"),t=Symbol("buttonGroup"),s=Symbol("dropdown"),c=Symbol("modals"),l=Symbol("floating"),y=Symbol("overlay"),n=Symbol("select"),b=Symbol("selectShow"),a=Symbol("selectFocusId"),m=Object.freeze(Object.defineProperty({__proto__:null,buttonGroupKey:t,dropdownKey:s,floatingKey:l,focusIdKey:a,modalsKey:c,overlayKey:y,sectionKey:e,selectKey:n,showKey:b,touchDeviceKey:o},Symbol.toStringTag,{value:"Module"}));export{m as c,l as f,c as m,y as o,n as s,o as t};
