import{k as i,o as y,v as T,R as f,S as l,z as m,y as p,A as d,T as A,V as R}from"./Dpn8_Hnn.mjs";import{B as g}from"./Bg0ZbUei.mjs";function N(_,h,e){var s;i&&(s=R,y());var r=new g(_);T(()=>{var o;var a=(o=h())!=null?o:null;if(i){var c=l(s),u=c===A,v=a!==null;if(u!==v){var t=m();p(t),r.anchor=t,d(!1),r.ensure(a,a&&(n=>e(n,a))),d(!0);return}}r.ensure(a,a&&(n=>e(n,a)))},f)}export{N as c};
