import"./E-vkuI0X.mjs";import"./DueIe5zz.mjs";import{h as p,r as h,b as v,c as s,e as b,f as u,j as _}from"./Dpn8_Hnn.mjs";import{s as g}from"./CXHdal8Z.mjs";import{b as k,s as C}from"./mb_JAnfe.mjs";import{b as y}from"./CcCPeAdh.mjs";import{p as i}from"./CUWjGq9Z.mjs";import{C as S}from"./CCAgu_H0.mjs";var j=_("<div><!></div>");function D(o,e){let m=i(e,"id",8,void 0),n=i(e,"class",8,""),l=i(e,"height",12,0),f=i(e,"breakpoint",8,"fluid");var t=j(),d=p(t);S(d,{get breakpoint(){return f()},children:(a,x)=>{var r=b(),c=u(r);g(c,e,"default",{}),s(a,r)},$$slots:{default:!0}}),h(t),v(()=>{var a;k(t,"id",m()),C(t,1,`sticky-container ${(a=n())!=null?a:""}`,"svelte-123l061")}),y(t,"offsetHeight",l),s(o,t)}export{D as S};
