.form-switch.svelte-184lr4n{padding-left:.5em}.form-check-input.svelte-184lr4n{-webkit-appearance:none;-moz-appearance:none;appearance:none;height:1.5em;margin-top:0}.form-switch.svelte-184lr4n .form-check-input:where(.svelte-184lr4n){width:3em;margin-left:1.5em;cursor:pointer}.nightMode.svelte-184lr4n:not(:checked){background-color:var(--canvas-elevated);border-color:var(--border)}.form-switch.rtl.svelte-184lr4n{padding-left:0;padding-right:.5em}.form-switch.rtl.svelte-184lr4n .form-check-input:where(.svelte-184lr4n){margin-left:0;margin-right:1.5em}
