import"./E-vkuI0X.mjs";import{i as b}from"./DueIe5zz.mjs";import{p as v,h as _,r as g,b as k,c as w,d as y,aj as S,j as T,ak as j}from"./Dpn8_Hnn.mjs";import{e as x}from"./B4YZClIG.mjs";import{a as C,s as r,b as D}from"./mb_JAnfe.mjs";import{b as M}from"./BjcIi-eP.mjs";import{b as q}from"./BSceNU1G.mjs";import{p as a}from"./CUWjGq9Z.mjs";import{p as z}from"./evd6y-9U.mjs";var A=T('<div><input type="checkbox"/></div>');function N(l,t){v(t,!1);const m=()=>j(z,"$pageTheme",n),[n,c]=S();let p=a(t,"id",8),d=a(t,"value",12),f=a(t,"disabled",8,!1);const u=window.getComputedStyle(document.body).direction=="rtl";b();var s=A();let i;var e=_(s);C(e);let o;g(s),k(()=>{i=r(s,1,"form-check form-switch svelte-184lr4n",null,i,{rtl:u}),D(e,"id",p()),o=r(e,1,"form-check-input svelte-184lr4n",null,o,{nightMode:m().isDark}),e.disabled=f()}),M(e,d),x("input",e,function(h){q.call(this,t,h)}),w(l,s),y(),c()}export{N as S};
