# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: anki/github.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'anki/github.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from anki import generic_pb2 as anki_dot_generic__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61nki/github.proto\x12\x0b\x61nki.github\x1a\x12\x61nki/generic.proto\"2\n\x14LatestReleaseRequest\x12\x1a\n\x12include_prerelease\x18\x01 \x01(\x08\"R\n\rGithubRelease\x12\x10\n\x08tag_name\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x10\n\x08\x63hecksum\x18\x04 \x01(\t2\x0f\n\rGithubService2\xae\x01\n\x14\x42\x61\x63kendGithubService\x12Q\n\x10GetLatestRelease\x12!.anki.github.LatestReleaseRequest\x1a\x1a.anki.github.GithubRelease\x12\x43\n\x0f\x44ownloadRelease\x12\x1a.anki.github.GithubRelease\x1a\x14.anki.generic.StringB\x02P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'anki.github_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'P\001'
  _globals['_LATESTRELEASEREQUEST']._serialized_start=54
  _globals['_LATESTRELEASEREQUEST']._serialized_end=104
  _globals['_GITHUBRELEASE']._serialized_start=106
  _globals['_GITHUBRELEASE']._serialized_end=188
  _globals['_GITHUBSERVICE']._serialized_start=190
  _globals['_GITHUBSERVICE']._serialized_end=205
  _globals['_BACKENDGITHUBSERVICE']._serialized_start=208
  _globals['_BACKENDGITHUBSERVICE']._serialized_end=382
# @@protoc_insertion_point(module_scope)
