import{a as T}from"../chunks/CFQvUeAj.mjs";import{g as q,s as $}from"../chunks/BpKl0fJZ.mjs";import"../chunks/E-vkuI0X.mjs";import{i as y}from"../chunks/DueIe5zz.mjs";import{p as P,m as L,h as r,r as s,al as g,b as M,c as k,d as S,ak as R,aj as Y,j as x,s as z,g as D,bw as G,i as K,u as N}from"../chunks/Dpn8_Hnn.mjs";import{p as l}from"../chunks/CUWjGq9Z.mjs";import{s as _}from"../chunks/B4YZClIG.mjs";import{S as V}from"../chunks/CTJMvhJn.mjs";import{E as w}from"../chunks/DTHo7gyJ.mjs";const E="experimentalFeatures";async function A(){const t=await q(E);return t!=null?t:{}}const B=(async()=>({labPerfs:await T(A,e=>$(E,e))})),oe=Object.freeze(Object.defineProperty({__proto__:null,load:B},Symbol.toStringTag,{value:"Module"}));var H=x('<label class="svelte-1asgw1g"><div class="header svelte-1asgw1g"><b> </b> <div class="switch svelte-1asgw1g"><!></div></div> </label>');function J(t,e){P(e,!1);const n=()=>R(b(),"$labPerfs",c),[c,o]=Y();let i=l(e,"title",8),d=l(e,"description",8,""),m=l(e,"key",8),b=l(e,"labPerfs",8),p=L(n()[m()]);function C(a){const O=a.target;G(b(),{...n(),[m()]:O.checked})}y();var v=H(),f=r(v),u=r(f),F=r(u,!0);s(u);var h=g(u,2),j=r(h);V(j,{get id(){return i()},get value(){return D(p)},set value(a){z(p,a)},$$events:{input:C},$$legacy:!0}),s(h),s(f);var I=g(f);s(v),M(()=>{var a;_(F,i()),_(I,` ${(a=d())!=null?a:""}`)}),k(t,v),S(),o()}var Q=x('<div class="container svelte-nfrqha"><div class="alert alert-warning mb-0 svelte-nfrqha"><b>⚠️ Experimental Features</b> <br/> These features may change, break, or be removed without notice, use at your own risk.</div> <div class="lab-grid svelte-nfrqha"><!></div></div>');function ie(t,e){P(e,!1);const c=l(e,"data",8)().labPerfs;y();var o=Q(),i=g(r(o),2),d=r(i);J(d,{title:"Svelte note editor",description:"Replaces the legacy editor with a new Svelte-based implementation. May affect addon compatibility. You can also hold shift while opening the editor to temporarily toggle this option on or off.",get key(){return K(w),N(()=>w.SVELTE_EDITOR)},get labPerfs(){return c}}),s(i),s(o),k(t,o),S()}export{ie as component,oe as universal};
