import{X as g,am as d,an as l,ao as i,u as m,ap as b,g as p,i as v,ac as h,aq as k}from"./Dpn8_Hnn.mjs";function x(n=!1){const s=g,e=s.l.u;if(!e)return;let f=()=>v(s.s);if(n){let t=0,a={};const _=h(()=>{let c=!1;const r=s.s;for(const o in r)r[o]!==a[o]&&(a[o]=r[o],c=!0);return c&&t++,t});f=()=>p(_)}e.b.length&&d(()=>{u(s,f),i(e.b)}),l(()=>{const t=m(()=>e.m.map(b));return()=>{for(const a of t)typeof a=="function"&&a()}}),e.a.length&&l(()=>{u(s,f),i(e.a)})}function u(n,s){if(n.l.s)for(const e of n.l.s)p(e);s()}k();export{x as i};
